@@ -1,28 +1,5 @@
 context('Test getShp')
 
-
-test_that("downloadShp downloads shapefiles and loads them correctly",{
-  
-  skip_on_cran()
-  
-  test_URL <- utils::URLencode("https://malariaatlas.org/geoserver/ows?service=wfs&version=2.0.0&request=GetFeature&outputFormat=shape-zip&srsName=EPSG:4326&TypeName=mapadmin_0_2018&cql_filter=iso%20IN%20(%27BDI%27)")
-  
-  test_dlshp <- downloadShp(test_URL)
-  
-  #check that Shp folder is deleted on exit
-  expect_false("shp" %in% dir(tempdir()))
-  # check that downloaded object is as expected
-  expect_true(inherits(test_dlshp, "sf"))
-  expect_true(unique(test_dlshp$iso)=="BDI")
-
-  skip_on_cran()
-  # test as.MAPshp
-  test_dlshp <- getShp(ISO = "BDI", admin_level = "admin0")
-  
-  expect_true(inherits(test_dlshp, "sf"))
-  expect_true(unique(test_dlshp$iso)=="BDI")
-})
-
 test_that("getShp downloads the correct shapefiles and stores them",{
   
   skip_on_cran()
